<?php

namespace App\Http\Controllers;

use App\Models\Imagen_producto;
use App\Models\Producto;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ControllerDashboardProducto extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $user = Auth::user();
        $data = Producto::where('id_comercio', $user->id_usuario)->get();
        //dd($data);

        return view('usuario.productos.index', compact('data', 'user'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $user = Auth::user();
        return view('usuario.productos.create', compact('user'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $user = Auth::user();
        $producto = new Producto();

        $request->validate([
            'nombre' => ['required'],
            'descripcion' => ['required'],
            'precio' => ['required'],
            'ruta_img' => ['required'],

        ]);

        $producto->id_comercio = $user->id_usuario;
        $producto->nombre = $request->nombre;
        $producto->precio = $request->precio;
        $producto->descripcion = $request->descripcion;

        $ultimoProducto = Producto::orderByDesc('id_producto')->first();
        $last_id = $ultimoProducto->id_producto + 1;

        if ($request->hasFile('ruta_img')) {

            $archivo = $request->file('ruta_img');
            $nombreArchivo = 'img_principal_' . $last_id . '.' . $archivo->getClientOriginalExtension();
            $archivo->move(public_path('imgProductos'), $nombreArchivo);
            $producto->ruta_img = 'imgProductos/' . $nombreArchivo;
        }

        $producto->save();
        return $request->bandera == '1' ? redirect()->route('productos.show', $producto->id_producto) : redirect()->route('productos.index', $producto->id_producto);
    }


    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $user = Auth::user();
        $item = Producto::with('imagenes_producto')->find($id);
        return view('usuario.productos.addImagenes', compact('item', 'user'));
    }


    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $user = Auth::user();
        $item = Producto::find($id);
        return view('usuario.productos.edit', compact('item', 'user'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $item = Producto::find($id);

        $item->nombre = $request->nombre;
        $item->precio = $request->precio;
        $item->descripcion = $request->descripcion;

        if ($request->hasFile('ruta_img')) {
            $archivo = $request->file('ruta_img');
            $nombreArchivo = 'img_principal_' . $id . '.' . $archivo->getClientOriginalExtension();
            $archivo->move(public_path('imgProductos'), $nombreArchivo);
            $item->ruta_img = 'imgProductos/' . $nombreArchivo;
        }

        $item->save();

        $user = Auth::user();

        return redirect()->route('productos.index', compact('user'));
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $item = Producto::find($id);
        $item->delete();
        $user = Auth::user();

        return redirect()->route('productos.index', compact('user'));
    }


    public function storeImagenes(Request $request)
    {
        $request->validate([
            'ruta_img' => 'required|image',
            'id_producto' => 'required|exists:productos,id_producto'
        ]);

        $imagenes = new Imagen_producto();

        $ultimoProducto = Imagen_producto::orderByDesc('id_imagen_producto')->first();
        $last_id = $ultimoProducto->id_imagen_producto + 1;

        if ($request->hasFile('ruta_img')) {
            // $file = $request->file('ruta_img');
            // $destinationPath = 'ruta_img/';
            // $fileName = time() . '-' . $file->getClientOriginalName();
            // $file->move($destinationPath, $fileName);
            // $imagenes->ruta_img = $destinationPath . $fileName;

            $archivo = $request->file('ruta_img');
            $nombreArchivo = 'img_' . $last_id . '_producto_' . $request->id_producto . '.' . $archivo->getClientOriginalExtension();
            $archivo->move(public_path('imgGaleriaProducto'), $nombreArchivo);
            $imagenes->ruta_img = 'imgGaleriaProducto/' . $nombreArchivo;
        }

        $imagenes->id_producto = $request->id_producto;
        $imagenes->save();

        return back();
    }

    public function destroyImagenes(string $id)
    {
        $item = Imagen_producto::find($id);
        $ruta = $item->ruta_img;
        unlink($ruta);
        $item->delete();
        return back();
    }
}
