<?php

namespace App\Http\Controllers;

use App\Models\Comercio;
use App\Models\User;
use Illuminate\Foundation\Auth\User as AuthUser;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ControllerDashboardUsuarios extends Controller
{


    public function index()
    {

        $data = User::where('rol',2)->get();
        $user = Auth::user();
        return view('usuario.index', compact('data', 'user'));
    }

    public function create()
    {
        $user = Auth::user();
        return view('usuario.create',compact('user'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $user = Auth::user();
        $usuario = new User();

        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|unique:usuarios,email|max:255',
            'password' => 'required|string|max:255',
        ]);

        $usuario->name = $request->name;
        $usuario->email = $request->email;
        $usuario->password = $request->password;
        $usuario->save();

        $comercio = new Comercio();
        $comercio->nombre = $usuario->name;
        $comercio->id_usuario = $usuario->id_usuario;
        $comercio->save();

        return redirect()->route('usuarios.index');

    }
    

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
      
    }
    

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $user = Auth::user();
        $item = User::find($id);
        return view('usuario.edit', compact('item','user'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {

        //Actualizar el producto

        $item = User::find($id);
        $item->name = $request->name;
        $item->email = $request->email;
        $item->password = $request->password;
        $item->save();

        $user = Auth::user();

        return redirect()->route('usuarios.index',compact('user'));
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $item = User::find($id);
        $item->delete();
        $user = Auth::user();

        return redirect()->route('usuarios.index',compact('user'));
    }


    ///////////////////////////////         Login and Logout        /////////////////////////////////////


    public function register(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|unique:usuarios,email|max:255',
            'password' => 'required|string|max:255',
        ]);

        $user = new User();
        $user->name = $request->name;
        $user->email = $request->email;
        $user->password = $request->password;
        $user->save();

        $comercio = new Comercio();
        $comercio->nombre = $user->name;
        $comercio->id_usuario = $user->id_usuario;
        $comercio->save();

        session(['user' => $user]);

        return redirect()->route('comercio.edit', $comercio->id_comercio);
    }

    public function login(Request $request)
    {
        $request->validate([
            'name' => 'required|string',
            'password' => 'required|string',
        ]);

        $user = User::where('name', $request->name)->first();
        if ($user && $user->password == $request->password) {
            Auth::login($user);
            if ($user->rol == 1) {
                return redirect()->route('adminIndex');
            } else {
                return redirect()->route('adminIndex');
            }
        } else {
            return back()->withErrors(['name' => 'Credenciales incorrectas']);
        }
    }

    public function logout()
    {
        Auth::logout(); // Cierra la sesión del usuario autenticado.
        session()->forget('user'); // Limpia la información del usuario de la sesión.
        return redirect()->route('index'); // Redirige al usuario a la página de inicio.
    }
}
