<?php

namespace App\Http\Controllers;

use App\Models\Imagen_comercio;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ControllerGaleriaComercio extends Controller
{
    /**
     * Muestra todas las imágenes del comercio.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        $data = Imagen_comercio::where('id_comercio',$user->id_usuario)->get();
        return view('usuario.comercio.galeria', compact('data','user'));
    }

    /**
     * Muestra el formulario para crear una nueva imagen del comercio.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = Auth::user();
        $data = Imagen_comercio::where('id_comercio',$user->id_usuario)->get();
        return view('usuario.comercio.galeria',compact('user','data'));
    }

    /**
     * Almacena una nueva imagen del comercio en la base de datos.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'id_comercio' => 'required|integer',
            'ruta_img' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048', // validación para imágenes
        ]);

        $item = new Imagen_comercio();
        //$item->id_comercio = $request->input('id_comercio');
        $user = Auth::user();
        $item->id_comercio = $user->id_usuario;
        $ultimaImagenComercio = Imagen_comercio::orderByDesc('id_imagen_comercio')->first();
        $last_id = $ultimaImagenComercio->id_imagen_comercio + 1;

        if ($request->hasFile('ruta_img')) {
            $archivo = $request->file('ruta_img');
            $nombreArchivo = 'item_galeria_'.$last_id.'_com_'.$user->id_usuario.'.'.$archivo->getClientOriginalExtension();
            $archivo->move(public_path('imgGaleriaComercio'), $nombreArchivo);
            $item->ruta_img = 'imgGaleriaComercio/'.$nombreArchivo;
        }

        $item->save();

        return redirect()->route('galeriaComercio.create',compact('user'))->with('success', 'Imagen del comercio añadida correctamente.');
    }

    /**
     * Elimina la imagen del comercio especificada.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $imagen = Imagen_comercio::findOrFail($id);
        unlink($imagen->ruta_img);
        $imagen->delete();

        return redirect()->route('galeriaComercio.index')->with('success', 'Imagen del comercio eliminada correctamente.');
    }
}