@extends('administrador.app_admin')

@section('contenido')

    <form action="{{ route('comercio.update', $item) }}" method="POST" enctype="multipart/form-data">
        @csrf
        @method('PUT')

        <div class="row">



            <div class="col-xl-7">

                <div class="card card-round">
                    <div class="card-header">
                        <div class="card-head-row card-tools-still-right">
                            <div class="card-title">Información del comercio</div>

                            <div class="card-tools">
                                <a href="{{ route('comercio.index') }}" class="btn btn-outline-dark">Regresar</a>
                            </div>

                        </div>
                    </div>

                    <div class="card-body">

                        <div class="row">

                            <div class="col-xl-5">

                                <div class="form-group">
                                    <label class="fw-bolder">Nombre de comercio</label>
                                    <input type="text" name="nombre" class="form-control" value="{{ $item->nombre }}"
                                        required>
                                </div>

                                <div class="form-group">
                                    <label class="fw-bolder">Télefono</label>
                                    <input type="tel" name="telefono" class="form-control"
                                        placeholder="Ingresa el télefono del comercio" value="{{ $item->telefono }}"
                                        required>
                                </div>

                                <div class="form-group">
                                    <label class="fw-bolder">Correo</label>

                                    <div class="input-group mb-3">
                                        <span class="input-group-text">@</span> <input type="email" class="form-control"
                                            name="correo" placeholder="Ingresa el correo del comercio"
                                            value="{{ $item->correo }}" required />
                                    </div>

                                </div>

                                <div class="form-group">
                                    <label class="fw-bolder">Descripción</label>
                                    <textarea name="descripcion" class="form-control" rows="5" placeholder="Ingresa la descripción del comercio"
                                        required >{{ $item->descripcion }}</textarea>
                                </div>

                                <div class="form-group">
                                    <label class="fw-bolder">Imagen principal</label>
                                    <input type="file" name="imagen" class="form-control" id="imagen"
                                        accept="image/*" value="{{ $item->ruta_img }}" required>
                                </div>

                                <div class="form-group">
                                    <label class="fw-bolder">Facebook</label>
                                    <input type="text" name="facebook" class="form-control"
                                        placeholder="Ingresa la cuenta de facebook (Opcional)"
                                        value="{{ $item->enlace_facebook }}" >
                                </div>

                                <div class="form-group">
                                    <label class="fw-bolder">Instagram</label>
                                    <input type="text" name="instagram" class="form-control"
                                        placeholder="Ingresa la cuenta de Instagram (Opcional)"
                                        value="{{ $item->enlace_instagram }}">
                                </div>

                            </div>

                            <div class="col-xl-7">

                                <div class="form-group">

                                    <label class="fw-bolder">Dirección</label>
                                    <input type="text" id="place_input" class="form-control" name="dirreccion"
                                        value="{{ $item->dirreccion }}" required>
                                    <div id="map" class="mt-3" style="height: 44rem !important;"></div>
                                    <input type="hidden" id="latitud" name="latitud" value="{{ $item->latitud }}">
                                    <input type="hidden" id="longitud" name="longitud" value="{{ $item->longitud }}">
                                </div>

                            </div>


                        </div>

                    </div>
                </div>

            </div>

            <div class="col-xl-5">

                <div class="row">

                    <div class="col-xl-12">

                        <div class="card card-round">
                            <div class="card-header">

                                <div class="card-head-row card-tools-still-right">
                                    <div class="card-title">Categorias del comercio</div>

                                </div>

                            </div>
                            <div class="card-body">

                                <div class="form-group">

                                    <label class="fw-bolder">Agrega categorias al comercio</label>

                                    <div class="input-group mb-3">
                                        <select id="categorias" name="categorias" class="form-select">

                                            {{-- <option selected>Presiona aquí para ver las categorias disponibles</option> --}}
                                            @foreach ($all_categorias as $ac)
                                                <option value="{{ $ac->id_categoria }}">{{ $ac->nombre }}</option>
                                            @endforeach

                                        </select>
                                        <button type="button" id="addCategoria" class="btn btn-primary">Añadir</button>
                                    </div>

                                </div>

                                <div class="form-group">

                                    <div class="table-responsive">

                                        <table id="tabla_categorias" class="display table table-striped table-hover">
                                            <thead>
                                                <tr>
                                                    <th>Nombre</th>
                                                    <th style="width: 10%">Eliminar</th>
                                                </tr>
                                            </thead>
                                            <tbody id="filasCategorias">
                                                {{-- Categorias Agregadas --}}
                                                @foreach ($item->categorias as $c)
                                                    <tr>
                                                        <td>
                                                            {{ $c->categoria->nombre }}
                                                            <input type="hidden" name="categorias[]"
                                                                value = "{{ $c->id_categoria }}">
                                                        </td>

                                                        <td>
                                                            <button type="button" data-bs-toggle="tooltip"
                                                                class="btn btn-link btn-danger deleteCategoria">
                                                                <i class="fa fa-times"></i>
                                                            </button>
                                                        </td>
                                                    </tr>
                                                @endforeach
                                            </tbody>
                                        </table>

                                    </div>

                                </div>


                            </div>
                        </div>

                        <div class="row">

                            <div class="col-xl-12 text-end">
                                <button id="submit" type="submit" class="btn btn-lg btn-success">Actualizar</button>
                            </div>

                        </div>


                    </div>

                </div>

            </div>

        </div>

    </form>
    <div class="modal fade" id="mensajes" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h2 class="modal-title" id="tituloModal"></h2>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <h3 id="contenidoModal"></h3>
                </div>
            </div>
        </div>
    </div>
@endsection

@section('js')
    <script async
        src="https://maps.googleapis.com/maps/api/js?key=AIzaSyA6LH4NtKdH2AUFtAqiOeUTBysHAzmpBE8&libraries=places&callback=initMap">
    </script>
    <script>
        //Tables
        $("#tabla_categorias").DataTable({
            pageLength: 5,
        });

        //Categorias
        $(document).on('click', '#addCategoria', function() {
            agregarCategorias();
        });

        $(document).on('click', '.deleteCategoria', function() {
            $(this).parent().parent().remove();
        });

        $(document).on('click', '#submit', function() {
            let filasCategorias = document.getElementById('filasCategorias').children;
            if (filasCategorias.length === 0) {
                event.preventDefault();
                messages('Querido usuario', 'Debe agregar al menos una categoria');
            }
        });

        function agregarCategorias() {
            let opcion = $('#categorias option:selected');
            if (validarNuevaCategoria(opcion.val())) {
                let fila = `
            <tr>
                <td>
                    ` + opcion.text() + `
                    <input type="hidden" name="categorias[]" value = ` + parseInt(opcion.val()) + `>
                </td>

                <td>
                    <button type="button" data-bs-toggle="tooltip"
                        class="btn btn-link btn-danger deleteCategoria">
                        <i class="fa fa-times"></i>
                    </button>
                </td>
            </tr>
            `;
                $('#filasCategorias').append(fila);
            } else {
                messages('Ups!!', 'Esta categoria ya se encuentra agregada');
            }
        }

        function validarNuevaCategoria(id_categoria) {
            let salida = true;
            let i = 0
            $('input[name="categorias[]"]').each(function() {
                if ($(this).val() == id_categoria) {
                    salida = false;
                }
            });
            return salida;
        }

        //Modales
        function messages(titulo, contenido) {
            $('#tituloModal').html(titulo);
            $('#contenidoModal').html(contenido);
            var modal = new bootstrap.Modal(document.getElementById('mensajes'));
            modal.show();
        }

        //Maps
        const longitud = document.getElementById("longitud");
        const latitud = document.getElementById("latitud");

        const argCoords = {
            lat: parseFloat(latitud.value),
            lng: parseFloat(longitud.value)
        };

        console.log(argCoords);
        const mapDiv = document.getElementById("map");
        const input = document.getElementById("place_input");
        let map;
        let marker;
        let autocomplete;

        function initMap() {
            map = new google.maps.Map(mapDiv, {
                center: argCoords,
                zoom: 19,
            });
            marker = new google.maps.Marker({
                position: argCoords,
                map: map,
            });
            initAutocomplete();
        }

        function initAutocomplete() {
            autocomplete = new google.maps.places.Autocomplete(input);
            autocomplete.addListener('place_changed', function() {
                const place = autocomplete.getPlace();
                const location = place.geometry.location;
                map.setCenter(location);
                map.setZoom(19); // Ajusta el nivel de zoom según tus preferencias
                marker.setPosition(location);
                latitud.value = location.lat();
                longitud.value = location.lng();
            });
        }

        initMap();
    </script>
@endsection
