<?php

use App\Http\Controllers\ControllerDashboardComercio;
use App\Http\Controllers\ControllerDashboardProducto;
use App\Http\Controllers\ControllerGaleriaComercio;
use App\Http\Controllers\ControllerCategorias;
use App\Http\Controllers\ControllerDashboardUsuarios;
use App\Http\Controllers\ControllerIndex;
use App\Http\Controllers\ControllerSlider;
use Illuminate\Support\Facades\Auth;
use App\Mail\ContactoMailable;
use App\Models\Comercio;
use App\Models\User;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

// Rutas públicas

Route::get('/', [ControllerIndex::class, 'index']);

Route::get('/index', [ControllerIndex::class, 'index'])->name('index');

Route::get('/ComercioBusqueda', function () {
    return view('ComercioBusqueda');
});

Route::get('/comercioProducto', function () {
    return view('comercioProducto');
});

Route::get('/contactoComercio', function () {
    return view('contactoComercio');
});

//----- VISTAS LANDING
Route::get('/informacionComercio/{id}', [ControllerIndex::class, 'informacionComercio'])
    ->name('informacionComercio');

Route::get('/informacionComercio/productos/{id}', [ControllerIndex::class, 'ComercioProductos'])
    ->name('ComercioProductos');

Route::get('/informacionComercio/productos/landingProducto/{id}', [ControllerIndex::class, 'landingProductos'])
    ->name('landingProductos');

Route::get('/informacionComercio/galeriaComercio/{id}', [ControllerIndex::class, 'galeriaComercio'])
    ->name('galeriaComercio');

Route::get('/informacionComercio/contacto/{id}', [ControllerIndex::class, 'contactoComercio'])
    ->name('contactoComercio');

Route::get('/ListaComercios', [ControllerIndex::class, 'getListaComercios'])
    ->name('getListaComercios');

Route::get('/ListaComercios_porCategoria', [ControllerIndex::class, 'get_Comercios_porCategoria'])
    ->name('get_Comercios_porCategoria');

Route::get('/ListaComercios_porCategoria_v2/{id}', [ControllerIndex::class, 'get_Categoria_Comercio'])
    ->name('get_Categoria_Comercio');

Route::get('/getProducto_getCategoria', [ControllerIndex::class, 'busquedaProductosComercios'])
    ->name('busquedaProductosComercios');
//--------------


//Ruta Correo
Route::post('/mail', [ControllerIndex::class, 'mail'])->name('mail');


//---------------


//Rutas admin


Route::get('/galeriaComercio', function () {
    $user = Auth::user();
    return view('usuario/comercio/galeria', compact('user'));
});


Route::get('/createSlider', function () {
    return view('administrador/sliders/create');
});

Route::get('/updateSlider', function () {
    return view('administrador/sliders/update');
});

Route::get('login', function () {
    return view('login.login');
});

// Rutas para administradores (rol 1)
Route::middleware(['auth', 'role:1'])->group(function () {
    Route::resource('/categorias', ControllerCategorias::class);
    Route::resource('/sliders', ControllerSlider::class);
    Route::resource('/usuarios', ControllerDashboardUsuarios::class);
    Route::get('/indexUsuarios', [ControllerDashboardUsuarios::class, 'index'])->name('indexUsuarios');

});

// Rutas para usuarios (rol 2)
Route::middleware(['auth', 'role:2'])->group(function () {
    Route::resource('/comercio', ControllerDashboardComercio::class);
    Route::resource('/productos', ControllerDashboardProducto::class);
    Route::resource('galeriaComercio', ControllerGaleriaComercio::class);
    Route::post('/galeria/store', [ControllerGaleriaComercio::class, 'store'])->name('galeria.store');
    Route::post('productomagenes', [ControllerDashboardProducto::class, 'storeImagenes'])->name('imagenes_producto.store');
    Route::delete('productos/imagenes/{id}', [ControllerDashboardProducto::class, 'destroyImagenes'])->name('imagenes_producto.destroy');
});

// Rutas accesibles para todos los usuarios autenticados
Route::middleware(['auth'])->group(function () {
    Route::get('/administrador/index', function () {
        $user = Auth::user();
        $item = Comercio::find($user->id_usuario);
        return view('administrador/index', compact('user','item'));
    })->name('adminIndex');
});

Route::post('login', [ControllerDashboardUsuarios::class, 'login'])->name('login');
Route::post('register', [ControllerDashboardUsuarios::class, 'register'])->name('register');
Route::post('logout', [ControllerDashboardUsuarios::class, 'logout'])->name('logout');
